@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceCloneCommand|
-|''Version''|0.5.5|
+|''Version''|0.5.6|
 |''Description''|provides a toolbar command for cloning external tiddlers|
 |''Status''|stable|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceCloneCommand.js|
@@ -40,8 +40,7 @@ cmd.cloneTiddler = {
 		var tiddler = store.getTiddler(title);
 		if(tiddler) {
 			fieldsCache[title] = $.extend({}, tiddler.fields);
-			tiddler.fields["server.workspace"] = "bags/%0_private".
-				format([tiddlyspace.currentSpace.name]);
+			tiddler.fields["server.workspace"] = tiddlyspace.getCurrentWorkspace("private");
 			tiddler.fields["server.permissions"] = "read, write, create"; // no delete
 			delete tiddler.fields["server.page.revision"];
 			delete tiddler.fields["server.title"];
@@ -65,7 +64,9 @@ cmd.cloneTiddler = {
 			el.attr("tiddlyfields", fields);
 		}
 		cmd.editTiddler.handler.apply(this, arguments);
-		tiddler.fields["server.permissions"] += ", delete";
+		if(tiddler) {
+			tiddler.fields["server.permissions"] += ", delete";
+		}
 		return false;
 	}
 };
